@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
  /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -34,9 +35,7 @@
 #include <tools/errinf.hxx>
 #include <vcl/svapp.hxx>
 #include <basegfx/vector/b2dvector.hxx>
-#ifndef _SVX_SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
 #include <editeng/protitem.hxx>
 #include <editeng/brshitem.hxx>
 #include <editeng/frmdiritem.hxx>
@@ -118,7 +117,7 @@ void SwFEShell::ParkCursorInTab()
 {
     SwCursor * pSwCrsr = GetSwCrsr();
 
-    ASSERT(pSwCrsr, "no SwCursor");
+    OSL_ENSURE(pSwCrsr, "no SwCursor");
 
     SwPosition aStartPos = *pSwCrsr->GetPoint(), aEndPos = aStartPos;
 
@@ -583,7 +582,7 @@ void SwFEShell::_GetTabCols( SwTabCols &rToFill, const SwFrm *pBox ) const
                 {
                     pLastCols->SetLeftMin( nLeftMin );
 
-                    //ASSERT( bVert ||
+                    // OSL_ENSURE( bVert ||
                     //        pLastCols->GetLeftMin() == (pTab->Frm().*fnRect->fnGetLeft)(),
                     //        "GetTabCols: wrong result" )
 
@@ -1021,7 +1020,7 @@ BOOL SwFEShell::HasBoxSelection() const
             if( !pCNd )
             {
                 pCNd = GetDoc()->GetNodes().GoPrevious( &aIdx );
-                ASSERT( pCNd, "kein ContentNode in der Box ??" );
+                OSL_ENSURE( pCNd, "kein ContentNode in der Box ??" );
             }
             if( pPam->GetMark()->nContent == pCNd->Len() )
             {
@@ -1446,7 +1445,7 @@ USHORT SwFEShell::GetCurTabColNum() const
     USHORT nRet = 0;
 
     SwFrm *pFrm = GetCurrFrm();
-    ASSERT( pFrm, "Crsr geparkt?" );
+    OSL_ENSURE( pFrm, "Crsr geparkt?" );
 
     // pruefe ob vom aktuellen Crsr der SPoint/Mark in einer Tabelle stehen
     if( pFrm && pFrm->IsInTab() )
@@ -1570,7 +1569,7 @@ const SwCellFrm *lcl_FindFrm( const SwLayoutFrm *pLay, const Point &rPt,
 
                     // We first check if the given point is 'close' to the left or top
                     // border of the table frame:
-                    ASSERT( pFrm, "Nested table frame without outer table" )
+                    OSL_ENSURE( pFrm, "Nested table frame without outer table" );
                     SWRECTFN( pFrm )
                     const bool bRTL = pFrm->IsRightToLeft();
 
@@ -1668,7 +1667,7 @@ const SwCellFrm *lcl_FindFrm( const SwLayoutFrm *pLay, const Point &rPt,
                 if ( !bMouseMoveRowCols )
                 {
 
-                    ASSERT( pbCol && pbRow, "pbCol or pbRow missing" )
+                    OSL_ENSURE( pbCol && pbRow, "pbCol or pbRow missing" );
 
                     if ( bCloseToRow || bCloseToCol )
                     {
@@ -1717,7 +1716,7 @@ const SwCellFrm *lcl_FindFrm( const SwLayoutFrm *pLay, const Point &rPt,
     }
 
     // robust:
-    ASSERT( !pRet || pRet->IsCellFrm(), "lcl_FindFrm() is supposed to find a cell frame!" )
+    OSL_ENSURE( !pRet || pRet->IsCellFrm(), "lcl_FindFrm() is supposed to find a cell frame!" );
     return pRet && pRet->IsCellFrm() ? static_cast<const SwCellFrm*>(pRet) : 0;
 }
 
@@ -2217,7 +2216,7 @@ USHORT SwFEShell::GetCurMouseTabColNum( const Point &rPt ) const
     USHORT nRet = 0;
 
     const SwFrm *pFrm = GetBox( rPt );
-    ASSERT( pFrm, "Table not found" );
+    OSL_ENSURE( pFrm, "Table not found" );
     if( pFrm )
     {
         const long nX = pFrm->Frm().Left();
@@ -2284,13 +2283,13 @@ void SwFEShell::SetTblAttr( const SfxItemSet &rNew )
  */
 bool lcl_GoTableRow( SwCrsrShell* pShell, bool bUp )
 {
-    ASSERT( pShell != NULL, "need shell" );
+    OSL_ENSURE( pShell != NULL, "need shell" );
 
     bool bRet = false;
 
     SwPaM* pPam = pShell->GetCrsr();
     const SwStartNode* pTableBox = pPam->GetNode()->FindTableBoxStartNode();
-    ASSERT( pTableBox != NULL, "I'm living in a box... NOT!" );
+    OSL_ENSURE( pTableBox != NULL, "I'm living in a box... NOT!" );
 
     // move cursor to start node of table box
     pPam->GetPoint()->nNode = pTableBox->GetIndex();
@@ -2573,7 +2572,7 @@ BOOL SwFEShell::IsMouseTableRightToLeft(const Point &rPt) const
 {
     SwFrm *pFrm = (SwFrm *)GetBox( rPt );
     const SwTabFrm*  pTabFrm = pFrm ? pFrm->ImplFindTabFrm() : 0;
-    ASSERT( pTabFrm, "Table not found" );
+    OSL_ENSURE( pTabFrm, "Table not found" );
     return pTabFrm ? pTabFrm->IsRightToLeft() : FALSE;
 }
 
@@ -2591,3 +2590,4 @@ BOOL SwFEShell::IsTableVertical() const
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
