@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -251,7 +252,7 @@ void SwLayoutCache::Write( SvStream &rStream, const SwDoc& rDoc )
                                     pSub = pSub->GetNext();
                                 }
                                 pTab = pTab->GetFollow();
-                                ASSERT( pTab, "Table follow without master" );
+                                OSL_ENSURE( pTab, "Table follow without master" );
                             }
                         }
                         do
@@ -289,7 +290,7 @@ void SwLayoutCache::Write( SvStream &rStream, const SwDoc& rDoc )
                                     SwPageFrm *pTabPage = pTab->FindPageFrm();
                                     if( pTabPage != pPage )
                                     {
-                                        ASSERT( pPage->GetPhyPageNum() <
+                                        OSL_ENSURE( pPage->GetPhyPageNum() <
                                                 pTabPage->GetPhyPageNum(),
                                                 "Looping Tableframes" );
                                         pPage = pTabPage;
@@ -344,7 +345,7 @@ void SwLayoutCache::Write( SvStream &rStream, const SwDoc& rDoc )
     }
 }
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
 sal_Bool SwLayoutCache::CompareLayout( const SwDoc& rDoc ) const
 {
     sal_Bool bRet = sal_True;
@@ -471,7 +472,7 @@ void SwLayoutCache::ClearImpl()
 
 SwLayoutCache::~SwLayoutCache()
 {
-    ASSERT( !nLockCount, "Deleting a locked SwLayoutCache!?" );
+    OSL_ENSURE( !nLockCount, "Deleting a locked SwLayoutCache!?" );
     delete pImpl;
 }
 
@@ -540,7 +541,7 @@ SwLayHelper::~SwLayHelper()
 {
     if( pImpl )
     {
-        ASSERT( pDoc && pDoc->GetLayoutCache(), "Missing layoutcache" );
+        OSL_ENSURE( pDoc && pDoc->GetLayoutCache(), "Missing layoutcache" );
         pDoc->GetLayoutCache()->UnlockImpl();
     }
 }
@@ -658,18 +659,18 @@ BOOL SwLayHelper::CheckInsertPage()
                          bNextPageOdd, bInsertEmpty, FALSE, rpPage->GetNext() );
         if ( bEnd )
         {
-            ASSERT( rpPage->GetNext(), "Keine neue Seite?" );
+            OSL_ENSURE( rpPage->GetNext(), "Keine neue Seite?" );
             do
             {	rpPage = (SwPageFrm*)rpPage->GetNext();
             } while ( rpPage->GetNext() );
         }
         else
         {
-            ASSERT( rpPage->GetNext(), "Keine neue Seite?" );
+            OSL_ENSURE( rpPage->GetNext(), "Keine neue Seite?" );
             rpPage = (SwPageFrm*)rpPage->GetNext();
             if ( rpPage->IsEmptyPage() )
             {
-                ASSERT( rpPage->GetNext(), "Keine neue Seite?" );
+                OSL_ENSURE( rpPage->GetNext(), "Keine neue Seite?" );
                 rpPage = (SwPageFrm*)rpPage->GetNext();
             }
         }
@@ -735,7 +736,7 @@ void lcl_ApplyWorkaroundForB6375613( SwFrm* p_pFirstFrmOnNewPage )
                                         uno::UNO_QUERY );
             try
             {
-                xDocInfo->setPropertyValue( rtl::OUString::createFromAscii("WorkaroundForB6375613Applied"), uno::makeAny( true ) );
+                xDocInfo->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("WorkaroundForB6375613Applied")), uno::makeAny( true ) );
             }
             catch( uno::Exception& )
             {
@@ -891,7 +892,7 @@ BOOL SwLayHelper::CheckInsert( ULONG nNodeIndex )
                                 SwRowFrm* pHeadline = 0;
                                 while( nRowIdx < nRepeat )
                                 {
-                                    ASSERT( pTab->GetTable()->GetTabLines()[ nRowIdx ], "Table ohne Zeilen?" );
+                                    OSL_ENSURE( pTab->GetTable()->GetTabLines()[ nRowIdx ], "Table ohne Zeilen?" );
                                     pHeadline =
                                         new SwRowFrm( *pTab->GetTable()->GetTabLines()[ nRowIdx ] );
                                     pHeadline->SetRepeatedHeadline( true );
@@ -1239,7 +1240,7 @@ BOOL SwLayCacheIoImpl::OpenRec( BYTE cType )
 {
     BOOL bRes = TRUE;
     UINT16 nLvl = aRecTypes.Count();
-    ASSERT( nLvl == aRecSizes.Count(), "OpenRec: Level" );
+    OSL_ENSURE( nLvl == aRecSizes.Count(), "OpenRec: Level" );
     UINT32 nPos = pStream->Tell();
     if( bWriteMode )
     {
@@ -1258,8 +1259,8 @@ BOOL SwLayCacheIoImpl::OpenRec( BYTE cType )
         if( !nVal || cRecTyp != cType ||
             pStream->GetErrorCode() != SVSTREAM_OK || pStream->IsEof() )
         {
-            ASSERT( nVal, "OpenRec: Record-Header is 0" );
-            ASSERT( cRecTyp == cType,
+            OSL_ENSURE( nVal, "OpenRec: Record-Header is 0" );
+            OSL_ENSURE( cRecTyp == cType,
                     "OpenRec: Wrong Record Type" );
             aRecTypes[nLvl] = 0;
             aRecSizes[nLvl] = pStream->Tell();
@@ -1276,8 +1277,8 @@ BOOL SwLayCacheIoImpl::CloseRec( BYTE )
 {
     BOOL bRes = TRUE;
     UINT16 nLvl = aRecTypes.Count();
-    ASSERT( nLvl == aRecSizes.Count(), "CloseRec: wrong Level" );
-    ASSERT( nLvl, "CloseRec: no levels" );
+    OSL_ENSURE( nLvl == aRecSizes.Count(), "CloseRec: wrong Level" );
+    OSL_ENSURE( nLvl, "CloseRec: no levels" );
     if( nLvl )
     {
         nLvl--;
@@ -1296,7 +1297,7 @@ BOOL SwLayCacheIoImpl::CloseRec( BYTE )
         else
         {
             UINT32 n = aRecSizes[nLvl];
-            ASSERT( n >= nPos, "CloseRec: to much data read" );
+            OSL_ENSURE( n >= nPos, "CloseRec: to much data read" );
             if( n != nPos )
             {
                 pStream->Seek( n );
@@ -1359,7 +1360,7 @@ void SwLayCacheIoImpl::SkipRec()
 
 BYTE SwLayCacheIoImpl::OpenFlagRec()
 {
-    ASSERT( !bWriteMode, "OpenFlagRec illegal in write  mode" );
+    OSL_ENSURE( !bWriteMode, "OpenFlagRec illegal in write  mode" );
     BYTE cFlags;
     *pStream >> cFlags;
     nFlagRecEnd = pStream->Tell() + ( cFlags & 0x0F );
@@ -1368,9 +1369,9 @@ BYTE SwLayCacheIoImpl::OpenFlagRec()
 
 void SwLayCacheIoImpl::OpenFlagRec( BYTE nFlags, BYTE nLen )
 {
-    ASSERT( bWriteMode, "OpenFlagRec illegal in read  mode" );
-    ASSERT( (nFlags & 0xF0) == 0, "illegal flags set" );
-    ASSERT( nLen < 16, "wrong flag record length" );
+    OSL_ENSURE( bWriteMode, "OpenFlagRec illegal in read  mode" );
+    OSL_ENSURE( (nFlags & 0xF0) == 0, "illegal flags set" );
+    OSL_ENSURE( nLen < 16, "wrong flag record length" );
     BYTE cFlags = (nFlags << 4) + nLen;
     *pStream << cFlags;
     nFlagRecEnd = pStream->Tell() + nLen;
@@ -1380,12 +1381,14 @@ void SwLayCacheIoImpl::CloseFlagRec()
 {
     if( bWriteMode )
     {
-        ASSERT( pStream->Tell() == nFlagRecEnd, "Wrong amount of data written" );
+        OSL_ENSURE( pStream->Tell() == nFlagRecEnd, "Wrong amount of data written" );
     }
     else
     {
-        ASSERT( pStream->Tell() <= nFlagRecEnd, "To many data read" );
+        OSL_ENSURE( pStream->Tell() <= nFlagRecEnd, "To many data read" );
         if( pStream->Tell() != nFlagRecEnd )
             pStream->Seek( nFlagRecEnd );
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
