@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -102,7 +103,7 @@ void Ww1SingleSprm::Start(
 void Ww1SingleSprm::Stop(
     Ww1Shell&, BYTE, BYTE*, USHORT, Ww1Manager&)
 {
-//	ASSERT(FALSE, "Unknown Sprm");
+// OSL_ENSURE(FALSE, "Unknown Sprm");
 }
 
 ////////////////////////////////////////////////////////////////// STOP
@@ -208,39 +209,49 @@ STOP1(Ww1SingleSprmPPageBreakBefore, RES_BREAK)
 SvxBorderLine* Ww1SingleSprmPBrc::SetBorder(SvxBorderLine* pLine, W1_BRC10* pBrc)
 {
     USHORT nCode;
+    SvxBorderStyle eStyle = SOLID;
     if(pBrc->dxpLine2WidthGet() == 0)
     {
         switch(pBrc->dxpLine1WidthGet())
         {
-        default: ASSERT(FALSE, "unknown linewidth");
+        default: OSL_ENSURE(FALSE, "unknown linewidth");
         case 0: return 0;							// keine Linie
         case 1: nCode = DEF_LINE_WIDTH_0; break;
         case 2: nCode = DEF_LINE_WIDTH_1; break;
         case 3: nCode = DEF_LINE_WIDTH_2; break;
         case 4: nCode = DEF_LINE_WIDTH_3; break;
         case 5: nCode = DEF_LINE_WIDTH_4; break;
+        case 6:
+                nCode = DEF_LINE_WIDTH_5;
+                eStyle = DOTTED;
+                break;
+        case 7:
+                nCode = DEF_LINE_WIDTH_5;
+                eStyle = DASHED;
+                break;
         }
         pLine->SetOutWidth(nCode);
         pLine->SetInWidth(0);
+        pLine->SetStyle( eStyle );
     }
     else
     {
         switch(pBrc->dxpLine1WidthGet())
         {
-        default: ASSERT(FALSE, "unknown linewidth");
+        default: OSL_ENSURE(FALSE, "unknown linewidth");
         case 1: nCode = DEF_DOUBLE_LINE0_IN; break;
         }
         pLine->SetOutWidth(nCode);
         switch(pBrc->dxpLine2WidthGet())
         {
-        default: ASSERT(FALSE, "unknown linewidth");
+        default: OSL_ENSURE(FALSE, "unknown linewidth");
         case 1: nCode = DEF_DOUBLE_LINE0_OUT; break;
         }
         pLine->SetInWidth(nCode);
     }
     switch(pBrc->dxpLine1WidthGet())
     {
-    default: ASSERT(FALSE, "unknown space");
+    default: OSL_ENSURE(FALSE, "unknown space");
     case 0: nCode = DEF_DOUBLE_LINE0_DIST; break;
     case 1: nCode = DEF_DOUBLE_LINE1_DIST; break;
     case 2: nCode = DEF_DOUBLE_LINE2_DIST; break;
@@ -254,14 +265,16 @@ void Ww1SingleSprmPBrc::Start(
     Ww1Shell& rOut, BYTE,
     W1_BRC10* pBrc,
     USHORT
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     nSize
 #endif
     ,
     Ww1Manager& /*rMan*/,
     SvxBoxItem& aBox)
 {
-    ASSERT(sizeof(W1_BRC10) == nSize, "sizemissmatch");
+#if OSL_DEBUG_LEVEL > 1
+    OSL_ENSURE(sizeof(W1_BRC10) == nSize, "sizemissmatch");
+#endif
     if(pBrc->dxpSpaceGet())
         aBox.SetDistance(10 + 20 * pBrc->dxpSpaceGet());
             //??? Warum 10+... ????
@@ -454,14 +467,16 @@ void Ww1SingleSprmPFInTable::Start(
 
 void Ww1SingleSprmPFInTable::Stop(
     Ww1Shell&
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     rOut
 #endif
     ,
     BYTE, BYTE*, USHORT,
     Ww1Manager& rMan)
 {
-    ASSERT(rOut.IsInTable(), "");
+#if OSL_DEBUG_LEVEL > 1
+    OSL_ENSURE(rOut.IsInTable(), "");
+#endif
     rMan.SetInTtp( FALSE );
 }
 
@@ -537,7 +552,7 @@ void Ww1SingleSprmTDefTable10::Start(
         if( pTc0 ){						// gibts TCs ueberhaupt ?
             W1_TC* pTc2 = (W1_TC*)pTc0;
             BOOL bMerged2 = pTc2->fMergedGet();
-//			ASSERT( !bMerged2, "Gemergte Tabellenzellen noch nicht vollstaendig implementiert" );
+//		 OSL_ENSURE( !bMerged2, "Gemergte Tabellenzellen noch nicht vollstaendig implementiert" );
             if( !bMerged2 ){
 // und nun die Umrandungen
                 SvxBoxItem aBox( (SvxBoxItem&)rOut.GetCellAttr( RES_BOX ));
@@ -682,3 +697,4 @@ void Ww1SingleSprmPFromText::Start(
 #undef STOP2
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
