@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,8 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
-
 #include <hintids.hxx>
 #include <vcl/font.hxx>
 #include <editeng/fontitem.hxx>
@@ -142,7 +141,7 @@ USHORT MSWordExportBase::GetId( const SwNumRule& rNumRule )
 //here in the ww export filter
 sal_Int16 GetWordFirstLineOffset(const SwNumFmt &rFmt)
 {
-    ASSERT( rFmt.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_WIDTH_AND_POSITION,
+    OSL_ENSURE( rFmt.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_WIDTH_AND_POSITION,
             "<GetWordFirstLineOffset> - misusage: position-and-space-mode does not equal LABEL_WIDTH_AND_POSITION" );
 
     short nFirstLineOffset;
@@ -268,7 +267,7 @@ void WW8AttributeOutput::NumberingLevel( BYTE /*nLevel*/,
             m_rWW8Export.InsUInt16( nFontID );
         }
 
-        m_rWW8Export.OutputItemSet( *pOutSet, false, true, i18n::ScriptType::LATIN );
+        m_rWW8Export.OutputItemSet( *pOutSet, false, true, i18n::ScriptType::LATIN, m_rWW8Export.mbExportModeRTF );
 
         m_rWW8Export.pO = pOldpO;
     }
@@ -360,7 +359,7 @@ void MSWordExportBase::AbstractNumberingDefinitions()
                     default:
                     {
                         nFollow = 0;
-                        ASSERT( false,
+                        OSL_ENSURE( false,
                                 "unknown GetLabelFollowedBy() return value" );
                     }
                 }
@@ -611,8 +610,8 @@ void WW8Export::Out_WwNumLvl( BYTE nWwLevel )
 void WW8Export::Out_SwNumLvl( BYTE nSwLevel )
 {
     // --> OD 2008-04-02 #refactorlists#
-//    ASSERT(IsNum(nSwLevel), "numbered?");
-    ASSERT( nSwLevel < MAXLEVEL, "numbered?");
+//    OSL_ENSURE(IsNum(nSwLevel), "numbered?");
+    OSL_ENSURE( nSwLevel < MAXLEVEL, "numbered?");
     // <--
     Out_WwNumLvl( nSwLevel + 1 );
 }
@@ -896,7 +895,7 @@ bool WW8Export::Out_SwNum(const SwTxtNode* pNd)
 
     if (nLevel < 0 || nLevel >= MAXLEVEL)
     {
-        ASSERT(FALSE, "Invalid level");
+        OSL_ENSURE(FALSE, "Invalid level");
 
         return false;
     }
@@ -956,4 +955,4 @@ bool WW8Export::Out_SwNum(const SwTxtNode* pNd)
     return bRet;
 }
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
