@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -32,8 +33,8 @@
 #define _SVSTDARR_STRINGS
 
 #include <com/sun/star/beans/PropertyAttribute.hpp>
-#include <vos/mutex.hxx>
-#include <tools/debug.hxx>
+#include <osl/mutex.hxx>
+#include <osl/diagnose.h>
 #include <vcl/svapp.hxx>
 #include <svl/svstdarr.hxx>
 #include <svtools/unoevent.hxx>
@@ -70,67 +71,48 @@ SV_IMPL_REF ( SwDocShell )
 using namespace ::com::sun::star;
 using ::rtl::OUString;
 
-/******************************************************************
- *
- ******************************************************************/
-/* -----------------30.03.99 14:31-------------------
- *
- * --------------------------------------------------*/
 uno::Reference< uno::XInterface > SAL_CALL SwXAutoTextContainer_createInstance(
     const uno::Reference< lang::XMultiServiceFactory > & ) throw( uno::Exception )
 {
     //the module may not be loaded
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     SwDLL::Init();
     static uno::Reference< uno::XInterface > xAText = (cppu::OWeakObject*)new SwXAutoTextContainer();;
     return xAText;
 }
-/* -----------------------------17.04.01 13:17--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Sequence< OUString > SAL_CALL SwXAutoTextContainer_getSupportedServiceNames() throw()
 {
     OUString sService( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.AutoTextContainer"));
     const uno::Sequence< OUString > aSeq( &sService, 1 );
     return aSeq;
 }
-/* -----------------------------17.04.01 13:18--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SAL_CALL SwXAutoTextContainer_getImplementationName() throw()
 {
     return OUString( RTL_CONSTASCII_USTRINGPARAM("SwXAutoTextContainer" ) );
 }
 
-/*-- 21.12.98 12:42:16---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXAutoTextContainer::SwXAutoTextContainer()
 {
     pGlossaries = ::GetGlossaries();
 
 }
-/*-- 21.12.98 12:42:17---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXAutoTextContainer::~SwXAutoTextContainer()
 {
 
 }
-/*-- 21.12.98 12:42:17---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Int32 SwXAutoTextContainer::getCount(void) throw( uno::RuntimeException )
 {
     return pGlossaries->GetGroupCnt();
 }
-/*-- 21.12.98 12:42:18---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Any SwXAutoTextContainer::getByIndex(sal_Int32 nIndex)
     throw( lang::IndexOutOfBoundsException, lang::WrappedTargetException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Any aRet;
     sal_uInt16 nCount = pGlossaries->GetGroupCnt();
     if ( 0 <= nIndex && nIndex < nCount )
@@ -139,29 +121,23 @@ uno::Any SwXAutoTextContainer::getByIndex(sal_Int32 nIndex)
         throw lang::IndexOutOfBoundsException();
     return aRet;
 }
-/*-- 21.12.98 12:42:18---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Type SwXAutoTextContainer::getElementType(void) throw( uno::RuntimeException )
 {
     return ::getCppuType((const uno::Reference<text::XAutoTextGroup>*)0);
 
 }
-/*-- 21.12.98 12:42:18---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXAutoTextContainer::hasElements(void) throw( uno::RuntimeException )
 {
     //zumindest Standard sollte es immer geben!
     return sal_True;
 }
-/*-- 21.12.98 12:42:18---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Any SwXAutoTextContainer::getByName(const OUString& GroupName)
     throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     uno::Reference< text::XAutoTextGroup > xGroup;
     if ( pGlossaries && hasByName( GroupName ) )	// group name already known?
@@ -173,12 +149,10 @@ uno::Any SwXAutoTextContainer::getByName(const OUString& GroupName)
 
     return makeAny( xGroup );
 }
-/*-- 21.12.98 12:42:19---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Sequence< OUString > SwXAutoTextContainer::getElementNames(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     sal_uInt16 nCount = pGlossaries->GetGroupCnt();
 
     uno::Sequence< OUString > aGroupNames(nCount);
@@ -198,20 +172,18 @@ uno::Sequence< OUString > SwXAutoTextContainer::getElementNames(void) throw( uno
 sal_Bool SwXAutoTextContainer::hasByName(const OUString& Name)
     throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     String sGroupName( pGlossaries->GetCompleteGroupName( Name ) );
     if(sGroupName.Len())
         return sal_True;
     return sal_False;
 }
-/*-- 21.12.98 12:42:19---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XAutoTextGroup >  SwXAutoTextContainer::insertNewByName(
     const OUString& aGroupName)
     throw( lang::IllegalArgumentException, container::ElementExistException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     if(hasByName(aGroupName))
         throw container::ElementExistException();
     //check for non-ASCII characters
@@ -246,34 +218,28 @@ uno::Reference< text::XAutoTextGroup >  SwXAutoTextContainer::insertNewByName(
     pGlossaries->NewGroupDoc(sGroup, sGroup.GetToken(0, GLOS_DELIM));
 
     uno::Reference< text::XAutoTextGroup > xGroup = pGlossaries->GetAutoTextGroup( sGroup, true );
-    DBG_ASSERT( xGroup.is(), "SwXAutoTextContainer::insertNewByName: no UNO object created? How this?" );
+    OSL_ENSURE( xGroup.is(), "SwXAutoTextContainer::insertNewByName: no UNO object created? How this?" );
         // we just inserted the group into the glossaries, so why doesn't it exist?
 
     return xGroup;
 }
-/*-- 21.12.98 12:42:19---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextContainer::removeByName(const OUString& aGroupName)
     throw( container::NoSuchElementException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     //zunaechst den Namen mit Pfad-Extension finden
     String sGroupName = pGlossaries->GetCompleteGroupName( aGroupName );
     if(!sGroupName.Len())
         throw container::NoSuchElementException();
     pGlossaries->DelGroupDoc(sGroupName);
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SwXAutoTextContainer::getImplementationName(void) throw( uno::RuntimeException )
 {
     return SwXAutoTextContainer_getImplementationName();
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 BOOL SwXAutoTextContainer::supportsService(const OUString& rServiceName) throw( uno::RuntimeException )
 {
     const uno::Sequence< OUString > aNames = SwXAutoTextContainer_getSupportedServiceNames();
@@ -284,27 +250,18 @@ BOOL SwXAutoTextContainer::supportsService(const OUString& rServiceName) throw(
     }
     return FALSE;
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Sequence< OUString > SwXAutoTextContainer::getSupportedServiceNames(void) throw( uno::RuntimeException )
 {
     return SwXAutoTextContainer_getSupportedServiceNames();
 }
-/******************************************************************
- *
- ******************************************************************/
-/* -----------------------------10.03.00 18:02--------------------------------
 
- ---------------------------------------------------------------------------*/
 const uno::Sequence< sal_Int8 > & SwXAutoTextGroup::getUnoTunnelId()
 {
     static uno::Sequence< sal_Int8 > aSeq = ::CreateUnoTunnelId();
     return aSeq;
 }
-/* -----------------------------10.03.00 18:04--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Int64 SAL_CALL SwXAutoTextGroup::getSomething( const uno::Sequence< sal_Int8 >& rId )
     throw(uno::RuntimeException)
 {
@@ -317,9 +274,6 @@ sal_Int64 SAL_CALL SwXAutoTextGroup::getSomething( const uno::Sequence< sal_Int8
     return 0;
 }
 
-/*-- 21.12.98 12:42:24---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXAutoTextGroup::SwXAutoTextGroup(const OUString& rName,
             SwGlossaries*	pGlos) :
     pPropSet(aSwMapProvider.GetPropertySet(PROPERTY_MAP_AUTO_TEXT_GROUP)),
@@ -327,25 +281,17 @@ SwXAutoTextGroup::SwXAutoTextGroup(const OUString& rName,
     sName(rName),
     m_sGroupName(rName)
 {
-    DBG_ASSERT( -1 != rName.indexOf( GLOS_DELIM ),
+    OSL_ENSURE( -1 != rName.indexOf( GLOS_DELIM ),
         "SwXAutoTextGroup::SwXAutoTextGroup: to be constructed with a complete name only!" );
 }
 
-/*-- 21.12.98 12:42:24---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXAutoTextGroup::~SwXAutoTextGroup()
 {
 }
-/*-- 21.12.98 12:42:24---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-/*-- 21.12.98 12:42:25---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Sequence< OUString > SwXAutoTextGroup::getTitles(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     sal_uInt16 nCount = 0;
     SwTextBlocks* pGlosGroup = pGlossaries ? pGlossaries->GetGroupDoc(m_sGroupName, sal_False) : 0;
     if(pGlosGroup && !pGlosGroup->GetError())
@@ -361,15 +307,13 @@ uno::Sequence< OUString > SwXAutoTextGroup::getTitles(void) throw( uno::RuntimeE
     delete pGlosGroup;
     return aEntryTitles;
 }
-/*-- 21.12.98 12:42:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::renameByName(const OUString& aElementName,
     const OUString& aNewElementName, const OUString& aNewElementTitle)
     throw( lang::IllegalArgumentException, container::ElementExistException, io::IOException,
                                                      uno::RuntimeException)
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     // throw exception only if the programmatic name is to be changed into an existing name
     if(aNewElementName != aElementName && hasByName(aNewElementName))
         throw container::ElementExistException();
@@ -400,7 +344,7 @@ void SwXAutoTextGroup::renameByName(const OUString& aElementName,
 
 sal_Bool lcl_CopySelToDoc( SwDoc* pInsDoc, OTextCursorHelper* pxCursor, SwXTextRange* pxRange)
 {
-    ASSERT( pInsDoc, "kein Ins.Dokument"  );
+    OSL_ENSURE( pInsDoc, "no InsDoc");
 
     SwNodes& rNds = pInsDoc->GetNodes();
 
@@ -435,14 +379,12 @@ sal_Bool lcl_CopySelToDoc( SwDoc* pInsDoc, OTextCursorHelper* pxCursor, SwXTextR
 
     return bRet;
 }
-/*-- 21.12.98 12:42:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XAutoTextEntry >  SwXAutoTextGroup::insertNewByName(const OUString& aName,
         const OUString& aTitle, const uno::Reference< text::XTextRange > & xTextRange)
         throw( container::ElementExistException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     if(hasByName(aName))
         throw container::ElementExistException();
     if(!xTextRange.is())
@@ -515,17 +457,15 @@ uno::Reference< text::XAutoTextEntry >  SwXAutoTextGroup::insertNewByName(const
     }
 
     uno::Reference< text::XAutoTextEntry > xEntry = pGlossaries->GetAutoTextEntry( m_sGroupName, sName, sShortName, true );
-    DBG_ASSERT( xEntry.is(), "SwXAutoTextGroup::insertNewByName: no UNO object created? How this?" );
+    OSL_ENSURE( xEntry.is(), "SwXAutoTextGroup::insertNewByName: no UNO object created? How this?" );
         // we just inserted the entry into the group, so why doesn't it exist?
 
     return xEntry;
 }
-/*-- 21.12.98 12:42:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::removeByName(const OUString& aEntryName) throw( container::NoSuchElementException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     SwTextBlocks* pGlosGroup = pGlossaries ? pGlossaries->GetGroupDoc(m_sGroupName, sal_False) : 0;
     if(pGlosGroup && !pGlosGroup->GetError())
     {
@@ -537,20 +477,16 @@ void SwXAutoTextGroup::removeByName(const OUString& aEntryName) throw( container
     else
         throw container::NoSuchElementException();
 }
-/*-- 21.12.98 12:42:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 OUString SwXAutoTextGroup::getName(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     return sName;
 }
-/*-- 21.12.98 12:42:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::setName(const OUString& rName) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     if( !pGlossaries )
         throw uno::RuntimeException();
 
@@ -593,12 +529,10 @@ void SwXAutoTextGroup::setName(const OUString& rName) throw( uno::RuntimeExcepti
         pGlossaries = pTempGlossaries;
     }
 }
-/*-- 21.12.98 12:42:26---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Int32 SwXAutoTextGroup::getCount(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     int nCount = 0;
     SwTextBlocks* pGlosGroup = pGlossaries ? pGlossaries->GetGroupDoc(m_sGroupName, sal_False) : 0;
     if(pGlosGroup && !pGlosGroup->GetError())
@@ -608,13 +542,11 @@ sal_Int32 SwXAutoTextGroup::getCount(void) throw( uno::RuntimeException )
     delete pGlosGroup;
     return nCount;
 }
-/*-- 21.12.98 12:42:26---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Any SwXAutoTextGroup::getByIndex(sal_Int32 nIndex)
     throw( lang::IndexOutOfBoundsException, lang::WrappedTargetException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Any aRet;
     sal_uInt16 nCount = 0;
     SwTextBlocks* pGlosGroup = pGlossaries ? pGlossaries->GetGroupDoc(m_sGroupName, sal_False) : 0;
@@ -629,20 +561,16 @@ uno::Any SwXAutoTextGroup::getByIndex(sal_Int32 nIndex)
     delete pGlosGroup;
     return aRet;
 }
-/*-- 21.12.98 12:42:26---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Type SwXAutoTextGroup::getElementType(void) throw( uno::RuntimeException )
 {
     return ::getCppuType((uno::Reference<text::XAutoTextEntry>*)0);
 
 }
-/*-- 21.12.98 12:42:26---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXAutoTextGroup::hasElements(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     SwTextBlocks* pGlosGroup = pGlossaries ? pGlossaries->GetGroupDoc(m_sGroupName, sal_False) : 0;
     sal_uInt16 nCount = 0;
     if(pGlosGroup && !pGlosGroup->GetError())
@@ -653,25 +581,21 @@ sal_Bool SwXAutoTextGroup::hasElements(void) throw( uno::RuntimeException )
     return nCount > 0;
 
 }
-/*-- 21.12.98 12:42:27---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Any SwXAutoTextGroup::getByName(const OUString& _rName)
     throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Reference< text::XAutoTextEntry > xEntry = pGlossaries->GetAutoTextEntry( m_sGroupName, sName, _rName, true );
-    DBG_ASSERT( xEntry.is(), "SwXAutoTextGroup::getByName: GetAutoTextEntry is fractious!" );
+    OSL_ENSURE( xEntry.is(), "SwXAutoTextGroup::getByName: GetAutoTextEntry is fractious!" );
         // we told it to create the object, so why didn't it?
     return makeAny( xEntry );
 }
-/*-- 21.12.98 12:42:27---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Sequence< OUString > SwXAutoTextGroup::getElementNames(void)
     throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     sal_uInt16 nCount = 0;
     SwTextBlocks* pGlosGroup = pGlossaries ? pGlossaries->GetGroupDoc(m_sGroupName, sal_False) : 0;
     if(pGlosGroup && !pGlosGroup->GetError())
@@ -687,13 +611,11 @@ uno::Sequence< OUString > SwXAutoTextGroup::getElementNames(void)
     delete pGlosGroup;
     return aEntryNames;
 }
-/*-- 21.12.98 12:42:27---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwXAutoTextGroup::hasByName(const OUString& rName)
     throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     sal_Bool bRet = sal_False;
     sal_uInt16 nCount = 0;
     SwTextBlocks* pGlosGroup = pGlossaries ? pGlossaries->GetGroupDoc(m_sGroupName, sal_False) : 0;
@@ -715,24 +637,19 @@ sal_Bool SwXAutoTextGroup::hasByName(const OUString& rName)
     return bRet;
 }
 
-/*-- 09.02.00 15:33:30---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Reference< beans::XPropertySetInfo >  SwXAutoTextGroup::getPropertySetInfo(void)
     throw( uno::RuntimeException )
 {
     static uno::Reference< beans::XPropertySetInfo >  xRet = pPropSet->getPropertySetInfo();
     return xRet;
 }
-/*-- 09.02.00 15:33:31---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::setPropertyValue(
     const OUString& rPropertyName, const uno::Any& aValue)
     throw( beans::UnknownPropertyException, beans::PropertyVetoException,
          lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException)
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     const SfxItemPropertySimpleEntry*   pEntry = pPropSet->getPropertyMap()->getByName( rPropertyName );
 
     if(!pEntry)
@@ -758,13 +675,11 @@ void SwXAutoTextGroup::setPropertyValue(
     }
     delete pGlosGroup;
 }
-/*-- 09.02.00 15:33:31---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Any SwXAutoTextGroup::getPropertyValue(const OUString& rPropertyName)
     throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     const SfxItemPropertySimpleEntry*   pEntry = pPropSet->getPropertyMap()->getByName( rPropertyName);
 
     if(!pEntry)
@@ -786,64 +701,48 @@ uno::Any SwXAutoTextGroup::getPropertyValue(const OUString& rPropertyName)
     delete pGlosGroup;
     return aAny;
 }
-/*-- 09.02.00 15:33:31---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::addPropertyChangeListener(
     const OUString& /*PropertyName*/, const uno::Reference< beans::XPropertyChangeListener > & /*aListener*/)
     throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
 }
-/*-- 09.02.00 15:33:31---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::removePropertyChangeListener(
     const OUString& /*PropertyName*/, const uno::Reference< beans::XPropertyChangeListener > & /*aListener*/)
     throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
 }
-/*-- 09.02.00 15:33:32---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::addVetoableChangeListener(
     const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/)
     throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
 }
-/*-- 09.02.00 15:33:32---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::removeVetoableChangeListener(
     const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/)
     throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
 }
-/*-- 21.12.98 12:42:27---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextGroup::Invalidate()
 {
     pGlossaries = 0;
     sName = aEmptyStr;
     m_sGroupName = aEmptyStr;
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SwXAutoTextGroup::getImplementationName(void) throw( uno::RuntimeException )
 {
     return C2U("SwXAutoTextGroup");
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 BOOL SwXAutoTextGroup::supportsService(const OUString& rServiceName) throw( uno::RuntimeException )
 {
     return C2U("com.sun.star.text.AutoTextGroup") == rServiceName;
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Sequence< OUString > SwXAutoTextGroup::getSupportedServiceNames(void) throw( uno::RuntimeException )
 {
     uno::Sequence< OUString > aRet(1);
@@ -851,20 +750,13 @@ uno::Sequence< OUString > SwXAutoTextGroup::getSupportedServiceNames(void) throw
     pArray[0] = C2U("com.sun.star.text.AutoTextGroup");
     return aRet;
 }
-/******************************************************************
- *
- ******************************************************************/
-/* -----------------------------10.03.00 18:02--------------------------------
 
- ---------------------------------------------------------------------------*/
 const uno::Sequence< sal_Int8 > & SwXAutoTextEntry::getUnoTunnelId()
 {
     static uno::Sequence< sal_Int8 > aSeq = ::CreateUnoTunnelId();
     return aSeq;
 }
-/* -----------------------------10.03.00 18:04--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Int64 SAL_CALL SwXAutoTextEntry::getSomething( const uno::Sequence< sal_Int8 >& rId )
     throw(uno::RuntimeException)
 {
@@ -876,9 +768,7 @@ sal_Int64 SAL_CALL SwXAutoTextEntry::getSomething( const uno::Sequence< sal_Int8
     }
     return 0;
 }
-/*-- 21.12.98 12:42:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXAutoTextEntry::SwXAutoTextEntry(SwGlossaries* pGlss, const String& rGroupName,
                                             const String& rEntryName) :
     pGlossaries(pGlss),
@@ -887,13 +777,11 @@ SwXAutoTextEntry::SwXAutoTextEntry(SwGlossaries* pGlss, const String& rGroupName
     pBodyText ( NULL )
 {
 }
-/*-- 21.12.98 12:42:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXAutoTextEntry::~SwXAutoTextEntry()
 {
     {
-        ::vos::OGuard aGuard(Application::GetSolarMutex());
+        SolarMutexGuard aGuard;
 
         // ensure that any pending modifications are written
         implFlushDocument( true );
@@ -905,9 +793,6 @@ SwXAutoTextEntry::~SwXAutoTextEntry()
     }
 }
 
-//---------------------------------------------------------------------
-//--- 03.03.2003 13:24:58 -----------------------------------------------
-
 void SwXAutoTextEntry::implFlushDocument( bool _bCloseDoc )
 {
     if ( xDocSh.Is() )
@@ -926,9 +811,6 @@ void SwXAutoTextEntry::implFlushDocument( bool _bCloseDoc )
     }
 }
 
-//-----------------------------------------------------------------------
-//--- 03.03.2003 15:51:52 -----------------------------------------------
-
 void SwXAutoTextEntry::Notify( SfxBroadcaster& _rBC, const SfxHint& _rHint )
 {
     if ( &_rBC == &xDocSh )
@@ -959,10 +841,10 @@ void SwXAutoTextEntry::Notify( SfxBroadcaster& _rBC, const SfxHint& _rHint )
 
 void SwXAutoTextEntry::GetBodyText ()
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     xDocSh = pGlossaries->EditGroupDoc ( sGroupName, sEntryName, FALSE );
-    DBG_ASSERT( xDocSh.Is(), "SwXAutoTextEntry::GetBodyText: unexpected: no doc returned by EditGroupDoc!" );
+    OSL_ENSURE( xDocSh.Is(), "SwXAutoTextEntry::GetBodyText: unexpected: no doc returned by EditGroupDoc!" );
 
     // start listening at the document
     StartListening( *&xDocSh );
@@ -973,114 +855,92 @@ void SwXAutoTextEntry::GetBodyText ()
 
 uno::Reference< text::XTextCursor >  SwXAutoTextEntry::createTextCursor(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     return pBodyText->createTextCursor();
 }
-/*-- 21.12.98 12:42:34---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextCursor >  SwXAutoTextEntry::createTextCursorByRange(
     const uno::Reference< text::XTextRange > & aTextPosition) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     return pBodyText->createTextCursorByRange ( aTextPosition );
 }
-/*-- 21.12.98 12:42:34---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextEntry::insertString(const uno::Reference< text::XTextRange > & xRange, const OUString& aString, sal_Bool bAbsorb) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     pBodyText->insertString ( xRange, aString, bAbsorb );
 }
-/*-- 21.12.98 12:42:34---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextEntry::insertControlCharacter(const uno::Reference< text::XTextRange > & xRange,
     sal_Int16 nControlCharacter, sal_Bool bAbsorb)
         throw( lang::IllegalArgumentException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     pBodyText->insertControlCharacter ( xRange, nControlCharacter, bAbsorb );
 }
-/*-- 21.12.98 12:42:34---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextEntry::insertTextContent(
     const uno::Reference< text::XTextRange > & xRange,
     const uno::Reference< text::XTextContent > & xContent, sal_Bool bAbsorb)
         throw( lang::IllegalArgumentException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     pBodyText->insertTextContent ( xRange, xContent, bAbsorb );
 }
-/*-- 21.12.98 12:42:34---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextEntry::removeTextContent(
     const uno::Reference< text::XTextContent > & xContent)
         throw( container::NoSuchElementException, uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     pBodyText->removeTextContent ( xContent );
 }
-/*-- 21.12.98 12:42:35---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XText >  SwXAutoTextEntry::getText(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Reference< text::XText >  xRet =  (text::XText*)this;
     return xRet;
 }
-/*-- 21.12.98 12:42:35---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextRange >  SwXAutoTextEntry::getStart(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     return pBodyText->getStart();
 }
-/*-- 21.12.98 12:42:36---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextRange >  SwXAutoTextEntry::getEnd(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     return pBodyText->getEnd();
 }
-/*-- 21.12.98 12:42:36---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 OUString SwXAutoTextEntry::getString(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     return pBodyText->getString();
 }
-/*-- 21.12.98 12:42:36---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXAutoTextEntry::setString(const OUString& aString) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     EnsureBodyText();
     pBodyText->setString( aString );
 }
-/* -----------------15.07.99 10:11-------------------
 
- --------------------------------------------------*/
 void SwXAutoTextEntry::applyTo(const uno::Reference< text::XTextRange > & xTextRange)throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     // ensure that any pending modifications are written
     // reason is that we're holding the _copy_ of the auto text, while the real auto text
@@ -1149,23 +1009,17 @@ void SwXAutoTextEntry::applyTo(const uno::Reference< text::XTextRange > & xTextR
     if(!bResult)
         throw uno::RuntimeException();
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SwXAutoTextEntry::getImplementationName(void) throw( uno::RuntimeException )
 {
     return C2U("SwXAutoTextEntry");
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 BOOL SwXAutoTextEntry::supportsService(const OUString& rServiceName) throw( uno::RuntimeException )
 {
     return C2U("com.sun.star.text.AutoTextEntry") == rServiceName;
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Sequence< OUString > SwXAutoTextEntry::getSupportedServiceNames(void) throw( uno::RuntimeException )
 {
     uno::Sequence< OUString > aRet(1);
@@ -1173,17 +1027,13 @@ uno::Sequence< OUString > SwXAutoTextEntry::getSupportedServiceNames(void) throw
     pArray[0] = C2U("com.sun.star.text.AutoTextEntry");
     return aRet;
 }
-/* -----------------------------06.04.00 11:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Reference< container::XNameReplace > SwXAutoTextEntry::getEvents()
     throw( uno::RuntimeException )
 {
     return new SwAutoTextEventDescriptor( *this );
 }
-/* -----------------------------30.01.01 18:40--------------------------------
 
- ---------------------------------------------------------------------------*/
 const struct SvEventDescription aAutotextEvents[] =
 {
     { SW_EVENT_START_INS_GLOSSARY,	"OnInsertStart" },
@@ -1191,9 +1041,6 @@ const struct SvEventDescription aAutotextEvents[] =
     { 0, NULL }
 };
 
-/* -----------------------------30.01.01 18:40--------------------------------
-
- ---------------------------------------------------------------------------*/
 SwAutoTextEventDescriptor::SwAutoTextEventDescriptor(
     SwXAutoTextEntry& rAutoText ) :
         SvBaseEventDescriptor(aAutotextEvents),
@@ -1202,23 +1049,17 @@ SwAutoTextEventDescriptor::SwAutoTextEventDescriptor(
         rAutoTextEntry(rAutoText)
 {
 }
-/* -----------------------------30.01.01 18:40--------------------------------
 
- ---------------------------------------------------------------------------*/
 SwAutoTextEventDescriptor::~SwAutoTextEventDescriptor()
 {
 }
-/* -----------------------------30.01.01 18:40--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SwAutoTextEventDescriptor::getImplementationName()
     throw( uno::RuntimeException )
 {
     return sSwAutoTextEventDescriptor;
 }
-/* -----------------------------30.01.01 18:40--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwAutoTextEventDescriptor::replaceByName(
     const USHORT nEvent,
     const SvxMacro& rMacro)
@@ -1228,16 +1069,16 @@ void SwAutoTextEventDescriptor::replaceByName(
                 lang::WrappedTargetException,
                 uno::RuntimeException)
 {
-    DBG_ASSERT( NULL != rAutoTextEntry.GetGlossaries(),
+    OSL_ENSURE( NULL != rAutoTextEntry.GetGlossaries(),
                 "Strangely enough, the AutoText vanished!" );
-    DBG_ASSERT( (nEvent == SW_EVENT_END_INS_GLOSSARY) ||
+    OSL_ENSURE( (nEvent == SW_EVENT_END_INS_GLOSSARY) ||
                 (nEvent == SW_EVENT_START_INS_GLOSSARY) ,
                 "Unknown event ID" );
 
     const SwGlossaries* pGlossaries = rAutoTextEntry.GetGlossaries();
     SwTextBlocks* pBlocks =
         pGlossaries->GetGroupDoc( rAutoTextEntry.GetGroupName() );
-    DBG_ASSERT( NULL != pBlocks,
+    OSL_ENSURE( NULL != pBlocks,
                 "can't get autotext group; SwAutoTextEntry has illegal name?");
 
     if( pBlocks && !pBlocks->GetError())
@@ -1258,9 +1099,7 @@ void SwAutoTextEventDescriptor::replaceByName(
     }
     // else: ignore
 }
-/* -----------------------------30.01.01 18:40--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwAutoTextEventDescriptor::getByName(
     SvxMacro& rMacro,
     const USHORT nEvent )
@@ -1269,15 +1108,15 @@ void SwAutoTextEventDescriptor::getByName(
                 lang::WrappedTargetException,
                 uno::RuntimeException)
 {
-    DBG_ASSERT( NULL != rAutoTextEntry.GetGlossaries(), "no AutoText" );
-    DBG_ASSERT( (nEvent == SW_EVENT_END_INS_GLOSSARY) ||
+    OSL_ENSURE( NULL != rAutoTextEntry.GetGlossaries(), "no AutoText" );
+    OSL_ENSURE( (nEvent == SW_EVENT_END_INS_GLOSSARY) ||
                 (nEvent == SW_EVENT_START_INS_GLOSSARY) ,
                 "Unknown event ID" );
 
     const SwGlossaries* pGlossaries = rAutoTextEntry.GetGlossaries();
     SwTextBlocks* pBlocks =
         pGlossaries->GetGroupDoc( rAutoTextEntry.GetGroupName() );
-    DBG_ASSERT( NULL != pBlocks,
+    OSL_ENSURE( NULL != pBlocks,
                 "can't get autotext group; SwAutoTextEntry has illegal name?");
 
     // return empty macro, unless macro is found
@@ -1306,3 +1145,4 @@ void SwAutoTextEventDescriptor::getByName(
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
